@@ -16,6 +16,14 @@
 # write to the Free Software Foundation, Inc., 51 Franklin Street,
 # Fifth Floor, Boston, MA 02110-1301 USA.
 
+if !defined?(GDK_PIXBUF)
+  if defined?(GdkPixbuf)
+    GDK_PIXBUF = GdkPixbuf::Pixbuf
+  else
+    GDK_PIXBUF = Gdk::Pixbuf
+  end
+end
+
 module Alexandria
   module UI
     MAX_RATING_STARS = 5
@@ -263,8 +271,8 @@ module Alexandria
         log.debug { "setting up active model" }
         # The active model.
 
-        list = [Gdk::Pixbuf,    # COVER_LIST
-          Gdk::Pixbuf,    # COVER_ICON
+        list = [GDK_PIXBUF,    # COVER_LIST
+          GDK_PIXBUF,    # COVER_ICON
           String,         # TITLE
           String,         # TITLE_REDUCED
           String,         # AUTHORS
